summaryrefslogtreecommitdiff
path: root/stc/stcenums.h
diff options
context:
space:
mode:
Diffstat (limited to 'stc/stcenums.h')
-rw-r--r--stc/stcenums.h35
1 files changed, 10 insertions, 25 deletions
diff --git a/stc/stcenums.h b/stc/stcenums.h
index b736359..28b5ad6 100644
--- a/stc/stcenums.h
+++ b/stc/stcenums.h
@@ -69,35 +69,20 @@ typedef enum
/**
* StcItemState:
* @STC_ITEM_STATE_NONE: No flags are set.
* @STC_ITEM_STATE_IS_APPLIED: A device/object matching the configuration item is already configured.
* @STC_ITEM_STATE_CAN_APPLY: The configuration can be applied (e.g. all requisite devices are present and all dependencies are fulfilled).
* @STC_ITEM_STATE_CAN_APPLY_DEGRADED: The configuration can be applied but the device will be started degraded.
*
- * Flag enumeration describing what state a configuration item currently is in.
- *
- * Note that %STC_ITEM_STATE_IS_APPLIED is set for an item even if the
- * requested options does not exactly match the request options. For
- * example, a %STC_ITEM_TYPE_FILESYSTEM configuration item may be set
- * if a filesystem matching the item is mounted but the mount options
- * doesn't match. On the other hand, for a filesystem, the mount path
- * needs to match - e.g. if the item has the option
- * <literal>Filesystem:mount_path</literal> set to
- * <filename>/mnt/bar</filename> then it won't be tagged with
- * %STC_ITEM_STATE_IS_APPLIED if the filesystem is mounted at
- * <filename>/mnt/foo</filename>.
- *
- * States %STC_ITEM_STATE_CAN_APPLY and
- * %STC_ITEM_STATE_CAN_APPLY_DEGRADED may be set even if
- * %STC_ITEM_STATE_IS_APPLIED is also set - e.g. they are independent
- * of whether the configuration is actually applied or not.
+ * Enumeration describing the current state of a configuration
+ * item
*/
typedef enum
{
- STC_ITEM_STATE_NONE = 0,
- STC_ITEM_STATE_IS_APPLIED = (1<<0),
- STC_ITEM_STATE_CAN_APPLY = (1<<1),
- STC_ITEM_STATE_CAN_APPLY_DEGRADED = (1<<2)
+ STC_ITEM_STATE_NOT_APPLIED,
+ STC_ITEM_STATE_CAN_APPLY_DEGRADED,
+ STC_ITEM_STATE_CAN_APPLY,
+ STC_ITEM_STATE_APPLIED,
} StcItemState;
G_END_DECLS
@@ -69,35 +69,20 @@ typedef enum
/**
* StcItemState:
- * @STC_ITEM_STATE_NONE: No flags are set.
- * @STC_ITEM_STATE_IS_APPLIED: A device/object matching the configuration item is already configured.
- * @STC_ITEM_STATE_CAN_APPLY: The configuration can be applied (e.g. all requisite devices are present and all dependencies are fulfilled).
- * @STC_ITEM_STATE_CAN_APPLY_DEGRADED: The configuration can be applied but the device will be started degraded.
+ * @STC_ITEM_STATE_NOT_APPLIED: Configuration item is not applied.
+ * @STC_ITEM_STATE_CAN_APPLY_DEGRADED: Like %STC_ITEM_STATE_CAN_APPLY but the device will be started degraded.
+ * @STC_ITEM_STATE_CAN_APPLY: The configuration item is not applied but it can be applied (e.g. all requisite devices are present and all dependencies are fulfilled).
+ * @STC_ITEM_STATE_APPLIED: The configuration item is applied.
*